﻿/*
 * SPiDER.Camera.js
 *
 * Copyright 2020
 * Carnegie Robotics LLC
 * 4501 Hatfield Street
 * Pittsburgh PA 15201
 * https://carnegierobotics.com
 */

SPiDER.camera = null;

SPiDER.createOrthographicCamera = function (domElement) {
    var width = $(domElement).width();
    var height = $(domElement).height();
    var scale = 2.75 * Math.sin(Math.PI * (25.0 / 180.0)) / height;

    var newCamera = new THREE.OrthographicCamera(-width * scale, width * scale, height * scale, -height * scale, 0.01, 2000.0);
    newCamera.position.y = 1.6;

    if (SPiDER.camera) {
        newCamera.zoom = SPiDER.camera.zoom;
        newCamera.updateProjectionMatrix();
    }

    SPiDER.camera = newCamera;
}

SPiDER.createPerspectiveCamera = function (domElement) {
    var width = $(domElement).width();
    var height = $(domElement).height();

    var newCamera = new THREE.PerspectiveCamera(50.0, width / height, 0.01, 2000.0);
    newCamera.position.y = 1.6;

    if (SPiDER.camera) {
        newCamera.zoom = SPiDER.camera.zoom;
        newCamera.updateProjectionMatrix();
    }

    SPiDER.camera = newCamera;
}

SPiDER.createDefaultCamera = function (domElement) {

    var width = $(domElement).width();
    var height = $(domElement).height();

    var projectionMode = window.localStorage.getItem('projectionMode');
    if (projectionMode === 'ORTHOGRAPHIC') {
        SPiDER.createOrthographicCamera(domElement);
    }
    else {
        SPiDER.createPerspectiveCamera(domElement);
    }
}

SPiDER.saveProjectionMode = function () {
    if (SPiDER.camera !== null) {
        var projectionMode = SPiDER.camera.type.slice(0, -6).toUpperCase();
        window.localStorage.setItem('projectionMode', projectionMode);
    }
}

SPiDER.resetProjectionMode = function () {
    window.localStorage.removeItem('projectionMode');
}
